# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .provider_link_response_state import ProviderLinkResponseState
import typing
from .provider_mfa_request import ProviderMfaRequest
from .password_providers import PasswordProviders
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProviderLinkResponse(UniversalBaseModel):
    state: ProviderLinkResponseState
    redirect_url: typing.Optional[str] = None
    error_type: typing.Optional[str] = None
    error: typing.Optional[str] = None
    provider_mfa: typing.Optional[ProviderMfaRequest] = None
    provider: PasswordProviders
    connected: bool
    provider_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
