# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .client_facing_provider import ClientFacingProvider
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class ConnectedSourceClientFacing(UniversalBaseModel):
    provider: ClientFacingProvider = pydantic.Field()
    """
    The provider of this connected source.
    """

    created_on: str = pydantic.Field()
    """
    When your item is created
    """

    source: ClientFacingProvider = pydantic.Field()
    """
    Deprecated. Use `provider` instead. Subject to removal after 1 Jan 2024.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
