# This file was auto-generated by Fern from our API Definition.

import typing
from .sleep_column_expr import SleepColumnExpr
from .activity_column_expr import ActivityColumnExpr
from .workout_column_expr import WorkoutColumnExpr
from .body_column_expr import BodyColumnExpr
from .index_column_expr import IndexColumnExpr
from .sleep_score_value_macro_expr import SleepScoreValueMacroExpr
from .chronotype_value_macro_expr import ChronotypeValueMacroExpr
from .unrecognized_value_macro_expr import UnrecognizedValueMacroExpr

AggregateExprArg = typing.Union[
    SleepColumnExpr,
    ActivityColumnExpr,
    WorkoutColumnExpr,
    BodyColumnExpr,
    IndexColumnExpr,
    SleepScoreValueMacroExpr,
    ChronotypeValueMacroExpr,
    UnrecognizedValueMacroExpr,
]
