# This file was auto-generated by Fern from our API Definition.

import enum


class VitalEnvironment(enum.Enum):
    PRODUCTION = "https://api.tryvital.io"
    PRODUCTION_EU = "https://api.eu.tryvital.io"
    SANDBOX = "https://api.sandbox.tryvital.io"
    SANDBOX_EU = "https://api.sandbox.eu.tryvital.io"
